@@ -1,7 +1,7 @@
 package CPAN::Reporter;
 use strict;
 
-$CPAN::Reporter::VERSION = "0.45"; 
+$CPAN::Reporter::VERSION = "0.46"; 
 
 use Config;
 use Config::Tiny ();
@@ -105,7 +105,7 @@ list, your test reports will not appear until manually reviewed.
 HERE
     },
     cc_author => {
-        default => 'default:yes pass:no',
+        default => 'default:yes pass/na:no',
         prompt => "Do you want to CC the the module author?",
         validate => 1,
         info => <<'HERE',
@@ -115,7 +115,7 @@ failed/unknown results. This option takes "grade:action" pairs.
 HERE
     },
     edit_report => {
-        default => 'default:ask/no pass:no',
+        default => 'default:ask/no pass/na:no',
         prompt => "Do you want to edit the test report?",
         validate => 1,
         info => <<'HERE',
@@ -127,7 +127,7 @@ report. This option takes "grade:action" pairs.
 HERE
     },
     send_report => {
-        default => 'default:ask/yes pass:yes na:no',
+        default => 'default:ask/yes pass/na:yes',
         prompt => "Do you want to send the test report?",
         validate => 1,
         info => <<'HERE',
@@ -216,7 +216,13 @@ sub configure {
         my $option_data = $defaults{$k};
         $CPAN::Frontend->myprint( "\n" . $option_data->{info}. "\n");
         # options with defaults are mandatory
-        if ( defined $defaults{$k}{default} ) {
+        if ( defined $option_data->{default} ) {
+            # if we have a default, always show as a sane recommendation
+            if ( length $option_data->{default} ) {
+                $CPAN::Frontend->myprint(
+                    "(Recommended: '$option_data->{default}')\n\n"
+                );
+            }
             # repeat until validated
             PROMPT:
             while ( my $answer = CPAN::Shell::colorable_makemaker_prompt(
@@ -312,7 +318,18 @@ sub test {
     $TEST_RESULT->close;
 
     _expand_report( $result );
-    _dispatch_report( $result );
+    
+    if ( $result->{grade} eq 'discard' ) {
+        $CPAN::Frontend->mywarn( 
+            "\nTest results were not valid: $result->{grade_msg}\n\n",
+            $result->{prereq_pm}, "\n",
+            "Test results for $result->{dist_name} will be discarded"
+        );
+    }
+    else {
+        _grade_msg( $result );
+        _dispatch_report( $result );
+    }
 
     return $result->{success};   # from _expand_report 
 }
@@ -449,7 +466,7 @@ sub _expand_report {
     $result->{env_vars} = _env_report();
     $result->{special_vars} = _special_vars_report();
     $result->{toolchain_versions} = _toolchain_report();
-    $result->{grade} = _grade_report($result);
+    _grade_report($result);
     $result->{success} =  $result->{grade} eq 'pass'
                        || $result->{grade} eq 'unknown';
     
@@ -575,7 +592,8 @@ sub _get_history_file {
 #--------------------------------------------------------------------------#
 
 sub _grade_msg {
-    my ($grade, $msg) = @_;
+    my ($result) = @_;
+    my ($grade, $msg) = ($result->{grade}, $result->{grade_msg});
     $CPAN::Frontend->myprint( "Test result is '$grade'");
     $CPAN::Frontend->myprint(": $msg") if defined $msg && length $msg;
     $CPAN::Frontend->myprint(".\n");
@@ -607,6 +625,10 @@ sub _grade_report {
             $grade = 'pass';
             $msg = 'All tests successful';
         }
+        elsif ( $output->[$i] =~ m{No support for OS|OS unsupported}ims ) {
+            $grade = 'na';
+            $msg = 'This platform is not supported';
+        }
         elsif ( $output->[$i] =~ m{^.?No tests defined}ms ) {
             $grade = 'unknown';
             $msg = 'No tests provided';
@@ -661,9 +683,15 @@ sub _grade_report {
     }
 
     # Downgrade failure/unknown grade if we can determine a cause
-    # that should be reported as 'na'.
+    # If perl version is too low => 'na'
+    # If stated prereqs missing => 'discard'
 
     if ( $grade eq 'fail' || $grade eq 'unknown' ) {
+        # check for unsupported OS
+        if ( $output =~ m{No support for OS|OS unsupported}ims ) {
+            $grade = 'na';
+            $msg = 'This platform is not supported';
+        }
         # check for perl version prerequisite or outright failure
         if ( $result->{prereq_pm} =~ m{^\s+!\s+perl\s}ims ) {
             $grade = 'na';
@@ -671,17 +699,18 @@ sub _grade_report {
         }
         # check the prereq report for missing or failure flag '!'
         elsif ( $result->{prereq_pm} =~ m{n/a}ims ) {
-            $grade = 'na';
+            $grade = 'discard';
             $msg = 'Prerequisite missing';
         }
         elsif ( $result->{prereq_pm} =~ m{^\s+!}ims ) {
-            $grade = 'na';
+            $grade = 'discard';
             $msg = 'Prerequisite version too low';
         }
     }
 
-    _grade_msg( $grade, $msg );
-    return $grade;
+    $result->{grade} = $grade;
+    $result->{grade_msg} = $msg;
+    return;
 }
 
 #--------------------------------------------------------------------------#
@@ -961,11 +990,10 @@ the results of the tests could not be parsed by CPAN::Reporter.
 HERE
 
     'na' => <<'HERE',
-Thank you for uploading your work to CPAN.  However, it appears that
-your distribution tests are not fully supported on this machine, either 
-due to operating system limitations or missing prerequisite modules.
-If the failure is due to missing prerequisites, you may wish to 
-disregard this report.
+Thank you for uploading your work to CPAN.  While attempting to test this
+distribution, the distribution signaled that support is not available either
+for this operating system or this version of Perl.  Nevertheless, any 
+diagnostic output produced is provided below for reference.
 HERE
     
 );
@@ -1350,11 +1378,11 @@ CPAN::Reporter will assign one of the following grades to the report:
 * {fail} -- one or more tests failed, one or more test files died during
 testing or no test output was seen
 
-* {na} -- tests could not be run on this platform or one or more test files
-died because of missing prerequisites
+* {na} -- tests could not be run on this platform or version of perl
 
 * {unknown} -- no test files could be found (either t/*.t or test.pl) or 
-a result could not be determined from test output
+a result could not be determined from test output (e.g tests may have hung 
+and been interrupted)
 
 * {default} -- this is not an actual grade reported to CPAN Testers, but it
 is used in action prompt configuration options to indicate a fallback action
@@ -1364,6 +1392,9 @@ attempts to "make test" or "Build test" and will not prevent installation.
 "fail" and "na" are considered to be failures and CPAN.pm will not install
 unless forced.
 
+If prerequisites specified in {Makefile.PL} or {Build.PL} are not available,
+no report will be generated and a failure will be signaled to CPAN.pm.
+
 = CONFIG FILE OPTIONS
 
 Default options for CPAN::Reporter are read from a configuration file 
@@ -1447,11 +1478,11 @@ Multiple grades may be specified together by separating them with a slash.
 The action prompt options are:
 
 * {cc_author = <grade:action> ...} -- should module authors should be sent a copy of 
-the test report at their {author@cpan.org} address? (default:yes pass:no)
+the test report at their {author@cpan.org} address? (default:yes pass/na:no)
 * {edit_report = <grade:action> ...} -- edit the test report before sending? 
-(default:ask/no pass:no)
+(default:ask/no pass/na:no)
 * {send_report = <grade:action> ...} -- should test reports be sent at all?
-(default:ask/yes pass:yes na:no)
+(default:ask/yes pass/na:yes)
 * {send_duplicates = <grade:action> ...} -- should duplicates of previous 
 reports be sent, regardless of {send_report}? (default:no)
 
@@ -1460,8 +1491,6 @@ first time CPAN::Reporter is configured interactively.
 
 Note that if {send_report} is set to "no", CPAN::Reporter will still go through
 the motions of preparing a report, but will discard it rather than send it.
-This is the default for an "na" report -- users may still edit the report to 
-see which prerequisites failed, but no report will be sent.
 
 A better way to disable CPAN::Reporter temporarily is with the CPAN option
 {test_report}:
@@ -1548,6 +1577,11 @@ Bugs can be submitted through the web interface at
 When submitting a bug or request, please include a test-file or a patch to an
 existing test-file that illustrates the bug or desired feature.
 
+= SEE ALSO
+
+* [http://cpantesters.perl.org] -- project home with all reports
+* [http://cpantest.grango.org] -- documentation and wiki
+
 = AUTHOR
 
 David A. Golden (DAGOLDEN)
